#ifndef NT2_INCLUDE_FUNCTIONS_IDXY_BILINEAR_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IDXY_BILINEAR_HPP_INCLUDED

#include <nt2/interpol/include/functions/idxy_bilinear.hpp>

#endif
